<?php
namespace App\Http\Controllers\Admin;

use App\Models\AdminRoleModel;
use App\Models\AdminUserModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class AdminUserController extends BaseController
{
    protected $model;

    protected $adminRole;

    protected $road;

    protected $zone;

    protected $model_name = '账号';

    protected $pre_uri = '/admin/AdminUser/';

    protected $view_path = 'admin.admin-users.';

    protected $redirect_index = '/admin/AdminUser/index';

    public function __construct()
    {
        parent::__construct();
        $this->model = new AdminUserModel();
        $this->adminRole = new AdminRoleModel();
    }

    public function index()
    {
        $admin_role_options = $this->adminRole->getOptions();
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'index', compact('model', 'model_name','pre_uri', 'admin_role_options'));
    }

    public function get(Request $request)
    {
        $items = $this->model->where('id', '>', 0);

        $tmp_items = collect(['name']);
        foreach($tmp_items as $tmp_item) {
            if($request->has($tmp_item) && !empty($request->input($tmp_item))) {
                $items = $items->where($tmp_item, 'like', '%' . $request->input($tmp_item) . '%');
            }
        }

        $select_items = collect([]);
        foreach($select_items as $select_item) {
            if($request->has($select_item) && !empty($request->input($select_item))) {
                $items = $items->where($select_item, '=', $request->input($select_item));
            }
        }

        $items = $items->paginate();
//        foreach($items as $item) {
//            $item->role_name = empty($item->adminRole) ? '' : $item->adminRole->name;
//        }
        return response()->json(['code' => 0, 'message' => '', 'count' => $items->total(), 'data' => $items->items()]);
    }

    public function create()
    {
        $admin_role_options = $this->adminRole->getOptions();
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'create', compact('model', 'model_name','pre_uri', 'admin_role_options'));
    }

    public function store(Request $request)
    {
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'store');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data = $request->input('data');
        unset($data['password_confirmation']);
        $data['password'] = bcrypt($data['password']);
        $res = $this->model->create($data);
        if(empty($res)) return back()->withErrors(['sg_error_info' => '保存失败']);
        return redirect($this->pre_uri . 'create')->with(['sg_success_info' => '创建成功']);
    }

    public function edit(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        $admin_role_options = $this->adminRole->getOptions();
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'edit', compact('model', 'model_name', 'pre_uri', 'item', 'admin_role_options'));
    }

    public function update(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'update');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        $data = $request->input('data');
        if(isset($data['password']) && !empty($data['password'])) {
            $data['password'] = bcrypt($data['password']);
        } else {
            unset($data['password']);
        }
        unset($data['password_confirmation']);
        $res = $this->model->where('id', $request->input('id'))->update($data);
        if(!$res) return back()->withErrors(['sg_error_info' => '数据库保存失败！']);
        return back()->with(['sg_success_info' => '编辑成功']);
    }

    public function delete(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return response()->json(['status' => 'fail', 'info' => '找不到要删除的数据']);
        $res = $item->delete();
        if (!$res) return response()->json(['status' => 'fail', 'info' => '删除失败']);
        return response()->json(['status' => 'success', 'info' => '操作成功']);
    }

    public function changePassword()
    {
        $item = Auth::guard('admin')->user();
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'change-password', compact('model', 'model_name', 'pre_uri', 'item'));
    }

    public function updatePassword(Request $request)
    {
        $validator = $this->model->getValidator($request, 'change-password');
        $user = Auth::guard('admin')->user();
        $data = $request->input('data');
        $validator->after(function ($validator) use($request, $data, $user) {
            if(!isset($data['old_password'])) {
                $validator->errors()->add('old_password', '请填写原来密码');
            } else if(!Hash::check($data['old_password'], $user['password'])) {
                $validator->errors()->add('old_password', '原来密码错误');
            }
        });
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        $this->model->where('id', $user['id'])->update(['password' => $data['password']]);

        return back()->with(['sg_success_info' => '操作成功']);
    }
}