<?php

namespace App\Http\Controllers\Admin;

use App\Models\InnerDevice;
use App\Models\InnerDeviceNamesModel;
use App\Models\Option;
use App\Models\Part;
use App\Models\RepairDevice;
use Illuminate\Http\Request;

class RepairDeviceController extends BaseController
{
    protected $model;

    protected $department;

    protected $model_name = '维修记录';

    protected $pre_uri = '/admin/RepairDevice/';

    protected $view_path = 'admin.repair-devices.';

    protected $redirect_index = '/admin/RepairDevice/index';

    public function __construct()
    {
        parent::__construct();
        $this->model = new RepairDevice();
    }

    public function index(Request $request)
    {
        $inner_device = InnerDevice::find($request->input('inner_device_id'));
        $inner_device->device_name_name = $inner_device->device_name ? $inner_device->device_name->name : '';
        $inner_device->spec_name = $inner_device->spec ? $inner_device->spec->name : '';
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'index', compact('model', 'model_name','pre_uri', 'inner_device'));
    }

    public function all(Request $request)
    {
        $status_label = Option::get('inner_devices','status');
        $inner_device_name = InnerDeviceNamesModel::getOptions();
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'all', compact('model', 'model_name','pre_uri','status_label','inner_device_name'));
    }

    public function get(Request $request)
    {
        $items = $this->model->orderBy('created_at', 'desc')->with(['inner_device']);
        //搜索名字
        $tmp_items = collect(['name']);
        foreach($tmp_items as $tmp_item) {
            if($request->has($tmp_item) && !empty($request->input($tmp_item))) {
                $items = $items->where($tmp_item, 'like', '%' . $request->input($tmp_item) . '%');
            }
        }

        //搜索内部设备id
        $select_items = collect(['inner_device_id']);
        foreach($select_items as $select_item) {
            if($request->has($select_item) && !empty($request->input($select_item))) {
                $items = $items->where($select_item, '=', $request->input($select_item));
            }
        }
        //查询状态
        if ($request->input('status_label'))
        {
            $items->whereHas('inner_device',function ($query){
               $query->where('status','=',request('status_label'));
            });
        }

        //查询设备名称
        if ($request->input('inner_device_name'))
        {
            $items->whereHas('inner_device',function ($query){
                $query->whereHas('device_name',function ($query){
                    $query->where('id','=',request('inner_device_name'));
                });
            });
        }
        //查询固定资产编号
        if ($request->input('number'))
        {
            $items->whereHas('inner_device',function ($query){
                    $query->where('number','like','%'.request('number').'%');
            });
        }
        //查询规格型号
        if ($request->input('spec_name'))
        {
            $items->whereHas('inner_device',function ($query){
                $query->where('spec_name','like','%'.request('spec_name').'%');
            });
        }
        //提交人
        if ($request->input('user_name'))
        {
            $items->whereHas('user',function ($query){
                $query->where('name','like','%'.request('user_name').'%');
            });
        }

        $items = $items->paginate();

        foreach ($items as $item) {
            $item->user_name = $item->user ? $item->user->name : '';
            $item->user_phone = $item->user ? $item->user->phone : '';
            $item->project_name = $item->project ? $item->project->name : '';
            $item->number = $item->inner_device ? $item->inner_device->number : '';
            $item->spec_name = $item->inner_device ? ($item->inner_device->spec_name ? $item->inner_device->spec_name : '') : '';
            $item->device_name = $item->inner_device ?
                ($item->inner_device->device_name ?
                    $item->inner_device->device_name->name ? $item->inner_device->device_name->name : ''
                    : '')
                : '';
            $item->work_point_name = $item->work_point ? $item->work_point->name : '';
            $item->status_label = $item->inner_device ? ($item->inner_device->option ? $item->inner_device->option->name :'' ) : '';
            $item->money = $item->money ? $item->money/100 : '';
        }

        return response()->json(['code' => 0, 'message' => '', 'count' => $items->total(), 'data' => $items->items()]);
    }

    public function create()
    {
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'create', compact('model', 'model_name','pre_uri'));
    }

    public function store(Request $request)
    {
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'store');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data = $request->input('data');
        $res = $this->model->create($data);
        if(empty($res)) return back()->withErrors(['sg_error_info' => '保存失败']);
        return redirect($this->pre_uri . 'create')->with(['sg_success_info' => '创建成功']);
    }

    public function edit(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        list($model, $model_name, $pre_uri) = array($this->model, $this->model_name, $this->pre_uri);
        return view($this->view_path . 'edit', compact('model', 'model_name', 'pre_uri', 'item'));
    }

    public function update(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return back()->withErrors(['sg_error_info' => '找不到要编辑的数据']);
        if(empty($request->input('data')) || !is_array($request->input('data'))) return back()->withErrors(['sg_error_info' => '数据错误']);
        $validator = $this->model->getValidator($request, 'update');
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data = $request->input('data');
        $res = $this->model->where('id', $request->input('id'))->update($data);
        if(!$res) return back()->withErrors(['sg_error_info' => '数据库保存失败！']);
        return back()->with(['sg_success_info' => '编辑成功']);
    }

    public function delete(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) return response()->json(['status' => 'fail', 'info' => '找不到要删除的数据']);
        Part::where('repair_device_id', $item->id)->delete();
        $res = $item->delete();
        if (!$res) return response()->json(['status' => 'fail', 'info' => '删除失败']);
        return response()->json(['status' => 'success', 'info' => '操作成功']);
    }
}
